==> claromentis-framework-9.6.6-26891208.zip: web/intranet/core/classes/Log/Levels.php <==
<?php
namespace Claromentis\Core\Log;

$GLOBALS["__65da1b1e" . "c2d6653e8a" . "0ab7848e53" . "6215"] = (@$GLOBALS["__65da1b1ec2d6653e8a0ab78" . "48e536215"] ?: array()) + array();
use Psr\Log\LogLevel;







class Levels
{
    
    
    
    
    
    
    
    
    
    public static function toNumber($_8571ac32155d45081f21fab1bc366aff)
    {
        static $levels = [LogLevel::EMERGENCY => 8, LogLevel::ALERT => 7, LogLevel::CRITICAL => 6, LogLevel::ERROR => 5, LogLevel::WARNING => 4, LogLevel::NOTICE => 3, LogLevel::INFO => 2, LogLevel::DEBUG => 1];
        return isset($levels[$_8571ac32155d45081f21fab1bc366aff]) ? $levels[$_8571ac32155d45081f21fab1bc366aff] : null;
    }
    
    
    
    
    
    
    
    
    public static function toString($_8571ac32155d45081f21fab1bc366aff)
    {
        static $levels = [LogLevel::EMERGENCY => 'emergency', LogLevel::ALERT => 'alert', LogLevel::CRITICAL => 'critical', LogLevel::ERROR => 'error', LogLevel::WARNING => 'warning', LogLevel::NOTICE => 'notice', LogLevel::INFO => 'info', LogLevel::DEBUG => 'debug'];
        return isset($levels[$_8571ac32155d45081f21fab1bc366aff]) ? $levels[$_8571ac32155d45081f21fab1bc366aff] : null;
    }
    
    
    
    
    
    
    
    
    public static function fromString($_b47ad6b3e449cba923c4b49063cceea3)
    {
        static $levels = ['emergency' => LogLevel::EMERGENCY, 'alert' => LogLevel::ALERT, 'critical' => LogLevel::CRITICAL, 'error' => LogLevel::ERROR, 'warning' => LogLevel::WARNING, 'notice' => LogLevel::NOTICE, 'info' => LogLevel::INFO, 'debug' => LogLevel::DEBUG];
        return isset($levels[$_b47ad6b3e449cba923c4b49063cceea3]) ? $levels[$_b47ad6b3e449cba923c4b49063cceea3] : null;
    }
}

==> claromentis-framework-10.3.3-59629072.zip: web/intranet/core/classes/Log/Levels.php <==
<?php
namespace Claromentis\Core\Log;

$GLOBALS["__65da1b1ec2d6653e8a0ab7848e" . "536215"] = (@$GLOBALS["__65da1b1e" . "c2d6653e8a" . "0ab7848e53" . "6215"] ?: array()) + array();
use Psr\Log\LogLevel;







class Levels
{
    
    
    
    
    
    
    
    
    
    public static function toNumber($_8571ac32155d45081f21fab1bc366aff)
    {
        static $levels = [LogLevel::EMERGENCY => 8, LogLevel::ALERT => 7, LogLevel::CRITICAL => 6, LogLevel::ERROR => 5, LogLevel::WARNING => 4, LogLevel::NOTICE => 3, LogLevel::INFO => 2, LogLevel::DEBUG => 1];
        return isset($levels[$_8571ac32155d45081f21fab1bc366aff]) ? $levels[$_8571ac32155d45081f21fab1bc366aff] : null;
    }
    
    
    
    
    
    
    
    
    public static function toString($_8571ac32155d45081f21fab1bc366aff)
    {
        static $levels = [LogLevel::EMERGENCY => 'emergency', LogLevel::ALERT => 'alert', LogLevel::CRITICAL => 'critical', LogLevel::ERROR => 'error', LogLevel::WARNING => 'warning', LogLevel::NOTICE => 'notice', LogLevel::INFO => 'info', LogLevel::DEBUG => 'debug'];
        return isset($levels[$_8571ac32155d45081f21fab1bc366aff]) ? $levels[$_8571ac32155d45081f21fab1bc366aff] : null;
    }
    
    
    
    
    
    
    
    
    public static function fromString($_b47ad6b3e449cba923c4b49063cceea3)
    {
        static $levels = ['emergency' => LogLevel::EMERGENCY, 'alert' => LogLevel::ALERT, 'critical' => LogLevel::CRITICAL, 'error' => LogLevel::ERROR, 'warning' => LogLevel::WARNING, 'notice' => LogLevel::NOTICE, 'info' => LogLevel::INFO, 'debug' => LogLevel::DEBUG];
        return isset($levels[$_b47ad6b3e449cba923c4b49063cceea3]) ? $levels[$_b47ad6b3e449cba923c4b49063cceea3] : null;
    }
}
